<?php

namespace FiloBlu\Newsletter\Controller;

class Router implements \Magento\Framework\App\RouterInterface {

    /**
     * @var \Magento\Framework\App\ActionFactory
     */
    protected $actionFactory;
    protected $_helper;
    protected $_modelLanding;
    protected $_modelPreConfirm;
    protected $_modelThankYou;

    public function __construct(
    \Magento\Framework\App\ActionFactory $actionFactory, \FiloBlu\Newsletter\Helper\Data $helper, \FiloBlu\Newsletter\Model\LandingPage $modelLanding, \FiloBlu\Newsletter\Model\PreConfirm $modelPreConfirm, \FiloBlu\Newsletter\Model\ThankYou $modelThankYou
    ) {
        $this->actionFactory = $actionFactory;
        $this->_helper = $helper;

        $this->_modelLanding = $modelLanding;
        $this->_modelPreConfirm = $modelPreConfirm;
        $this->_modelThankYou = $modelThankYou;
    }

    /**
     * Validate and Match Cms Page and modify request
     *
     * @param \Magento\Framework\App\RequestInterface $request
     * @return bool
     */
    public function match(\Magento\Framework\App\RequestInterface $request) {
        
        if ($this->_helper->getConfig("general/enabled")) {
            
            foreach ($this->_modelLanding->getAllUrlLandingPage()->getData() as $value) {
                $path = trim($request->getPathInfo(), '/');

                if ($path == $value["url_key"]) {

                    $request->setAlias(\Magento\Framework\UrlInterface::REWRITE_REQUEST_PATH_ALIAS, $path);
                    $request->setPathInfo('/' . 'newsletterajax/index/landingpage/landing_id/' . $value["landing_id"]);

                    return $this->actionFactory->create('Magento\Framework\App\Action\Forward');
                }
            }

            foreach ($this->_modelPreConfirm->getAllUrlPreConfirmPage()->getData() as $value) {
                
                if ($value["require_cookie"] && !$this->_helper->getPreConfirmCookie($value["preconfirm_id"])) {
                    continue;
                }
                
                $path = trim($request->getPathInfo(), '/');

                if ($path == $value["url_key"]) {
                    
                    $this->_helper->deletePreConfirmCookie($value["preconfirm_id"]);
                    $request->setAlias(\Magento\Framework\UrlInterface::REWRITE_REQUEST_PATH_ALIAS, $path);
                    $request->setPathInfo('/' . 'newsletterajax/index/preconfirm/preconfirm_id/' . $value["preconfirm_id"]);

                    return $this->actionFactory->create('Magento\Framework\App\Action\Forward');
                }
            }

            foreach ($this->_modelThankYou->getAllUrlThankYouPage()->getData() as $value) {
                
                 if ($value["require_cookie"] && !$this->_helper->getThankYouCookie($value["thankyou_id"])) {
                    continue;
                }
                
                $path = trim($request->getPathInfo(), '/');

                if ($path == $value["url_key"]) {

                    $this->_helper->deleteThankYouCookie($value["thankyou_id"]);
                    $request->setAlias(\Magento\Framework\UrlInterface::REWRITE_REQUEST_PATH_ALIAS, $path);
                    $request->setPathInfo('/' . 'newsletterajax/index/thankyou/thankyou_id/' . $value["thankyou_id"]);

                    return $this->actionFactory->create('Magento\Framework\App\Action\Forward');
                }
            }
        }
    }
}
